@@ -74,6 +74,10 @@
 #ifndef CORO_H
 #define CORO_H
 
+#if __cplusplus
+extern "C" {
+#endif
+
 #define CORO_VERSION 2
 
 /*
@@ -291,5 +295,9 @@ void coro_destroy (coro_context *ctx);
 
 #endif
 
+#if __cplusplus
+}
+#endif
+
 #endif
 
